@@ -62,15 +62,10 @@ def get_chemical_data(chemical):
     return {i:getfield(chemical, i) for i in chemical.__slots__}
 
 def unpickle_chemical(chemical_data):
-    cache = Chemical._cache
-    CAS = chemical_data['_CAS']
-    if CAS in cache:
-        chemical = cache[CAS]
-    else:
-        chemical = object.__new__(Chemical)
-        setfield = setattr
-        for field, value in chemical_data.items():
-            setfield(chemical, field, value)
+    chemical = object.__new__(Chemical)
+    setfield = setattr
+    for field, value in chemical_data.items():
+        setfield(chemical, field, value)
     return chemical
 
 
@@ -128,6 +123,11 @@ def raise_helpful_energy_functor_error(energy_functor):
                      "method to reset the free energy models with updated "
                      "chemical data")
 
+# %%  Utilities
+
+def as_chemical(chemical):
+    return chemical if isinstance(chemical, Chemical) else Chemical(chemical)
+
 # %% Chemical fields
 
 _names = ('_CAS',
@@ -486,17 +486,14 @@ class Chemical:
     #: [float] Reference entropy in J/mol
     S_ref = 0.
     
-    _cache = {}
-    
     ### Creators ###
     
     def __new__(cls, ID, *, search_ID=None,
                 eos=PR, phase_ref=None, CAS=None,
                 default=False, phase=None, search_db=True, 
                 V=None, Cn=None, mu=None, Cp=None, rho=None,
-                sigma=None, kappa=None, epsilon=None,
-                **data):
-        cache = cls._cache
+                sigma=None, kappa=None, epsilon=None, Psat=None,
+                Hvap=None, **data):
         search_ID = search_ID or ID
         if search_db:
             try:
@@ -505,31 +502,28 @@ class Chemical:
                 search_ID = to_searchable_format(search_ID)
                 try: CAS = CAS_from_any(search_ID)
                 except: raise Error
-            if CAS in cache:
-                self = cache[CAS]
-                if ID != self._ID:
-                    if ID in cache:
-                        self = cache[ID]
-                    else:
-                        cache[ID] = self = self.copy(ID=ID, CAS=self._CAS)
-                setfield = setattr
-                for i,j in data.items(): 
-                    if j is not None: setfield(self, i, j)
-            else:
-                self = super().__new__(cls)
-                self._ID = ID
-                self.reset(CAS, eos, phase_ref, **data)
-                cache[CAS] = self
+            self = cls.new(ID, CAS, eos, phase_ref, **data)
         else:
             self = cls.blank(ID, CAS, phase_ref, **data)
-        if phase: self = self.at_state(phase, copy=True)
-        if mu: self.mu.add_model(mu, top_priority=True)
-        if Cn: self.Cn.add_model(Cn, top_priority=True)
-        if kappa: self.kappa.add_model(kappa, top_priority=True)
+        if phase:
+            self.at_state(phase)
+            if mu: self.mu.add_model(mu, top_priority=True)
+            if Cn: self.Cn.add_model(Cn, top_priority=True)
+            if kappa: self.kappa.add_model(kappa, top_priority=True)
+            if Cp: self.Cn.add_model(Cp * self.MW, top_priority=True)
+            if rho: self.V.add_model(fn.rho_to_V(rho, self.MW), top_priority=True)
+        else:
+            multi_phase_items = (('mu', mu),
+                                 ('Cn', Cn),
+                                 ('kappa', kappa), 
+                                 ('Cp', Cp),
+                                 ('rho', rho))
+            for i,j in multi_phase_items:
+                if j: raise ValueError(f'must specify phase to set {i} model')
         if sigma: self.sigma.add_model(sigma, top_priority=True)
-        if epsilon: self.sigma.add_model(epsilon, top_priority=True)
-        if Cp: self.Cn.add_model(Cp * self.MW, top_priority=True)
-        if rho: self.V.add_model(fn.rho_to_V(rho, self.MW), top_priority=True)
+        if epsilon: self.epsilon.add_model(epsilon, top_priority=True)
+        if Psat: self.Psat.add_model(Psat, top_priority=True)
+        if Hvap: self.Hvap.add_model(Hvap, top_priority=True)
         if default: self.default()
         return self
 
@@ -537,14 +531,9 @@ class Chemical:
     def new(cls, ID, CAS, eos=PR, phase_ref=None, **data):
         """Create a new chemical from data without searching through
         the data base, and load all possible models from given data."""
-        cache = cls._cache
-        if CAS in cache:
-            raise RuntimeError(f'chemical with CAS {repr(CAS)} already created')                    
-        else:
-            self = super().__new__(cls)
-            self._ID = ID
-            self.reset(CAS, eos, phase_ref, **data)
-            cache[CAS] = self
+        self = super().__new__(cls)
+        self._ID = ID
+        self.reset(CAS, eos, phase_ref, **data)
         return self
 
     @classmethod
@@ -634,7 +623,7 @@ class Chemical:
         else: self._formula = formula
         return self
 
-    def copy(self, ID, CAS=None):
+    def copy(self, ID, CAS=None, **data):
         """Return a copy of the chemical with a new ID."""
         new = super().__new__(self.__class__)
         getfield = getattr
@@ -643,12 +632,13 @@ class Chemical:
             value = getfield(self, field)
             setfield(new, field, copy_maybe(value))
         new._ID = ID
-        new._CAS = CAS
+        new._CAS = CAS or ID
         new._locked_state = new._locked_state
         new._init_energies(new.Cn, new.Hvap, new.Psat, new.Hfus, new.Tm,
                            new.Tb, new.eos, new.eos_1atm, new.phase_ref,
                            new._locked_state)
         new._label_handles()
+        for i,j in data.items(): setfield(new, i , j)
         return new
     __copy__ = copy
 
@@ -1696,7 +1686,7 @@ class Chemical:
         0.0
         """
         if copy:
-            new = self.copy(self._ID, self._CAS)
+            new = self.copy(self._ID)
             new.at_state(phase)
             return new
         locked_state = self._locked_state
