@@ -1379,10 +1379,15 @@ class Stream:
         T = self.T
         return F_l(x, T).sum()
     
-    def receive_vent(self, other, accumulate=False):
+    def receive_vent(self, other, accumulate=False, fraction=1.0):
         """
         Receive vapors from another stream as if in equilibrium.
 
+        Notes
+        -----
+        Disregards energy balance. Assumes liquid composition will not change
+        significantly.
+
         Examples
         --------
         >>> import thermosteam as tmo
@@ -1399,6 +1404,8 @@ class Stream:
                          Ethanol  0.0616
                          N2       0.369
         """
+        # TODO: Add energy balance 
+        assert self.phase == 'g', 'stream must be a gas to receive vent'
         chemicals = other.vle_chemicals
         light_indices = other.chemicals._light_indices
         if accumulate:
@@ -1415,12 +1422,15 @@ class Stream:
         y = f_l / P
         imol = self.imol
         mol_old = imol[IDs]
+        mol_new = fraction * self.F_mol * y
         if accumulate:
-            mol_new = self.F_mol * y
             imol[IDs] += mol_new            
         else:
-            imol[IDs] = mol_new = self.F_mol * y
+            imol[IDs] = mol_new
         other.imol[IDs] += mol_old - mol_new 
+        index = other.mol < 0.
+        self.mol[index] += other.mol[index]
+        other.mol[index] = 0
         
     ### Casting ###
     
