@@ -120,7 +120,8 @@ class LLE:
     def get_liquid_mol_data(self):
         # Get flow rates
         imol = self._imol
-        mol = imol['l'] + imol['L']
+        imol['l'] = mol =  imol['l'] + imol['L']
+        imol['L'] = 0
         index = self.chemicals.get_lle_indices(mol > 0)
         mol = mol[index]
         chemicals = self.chemicals.tuple
