@@ -83,4 +83,4 @@ def dipole_moment(CASRN, method='Any'):
     .. [3] Poling, Bruce E. The Properties of Gases and Liquids. 5th edition.
        New York: McGraw-Hill Professional, 2000.
     '''
-    return get_from_data_sources(dipole_data_sources, 'CASRN', 'Dipole', method)
+    return get_from_data_sources(dipole_data_sources, CASRN, 'Dipole', method)
