@@ -25,8 +25,9 @@ __all__ = (
     'compute_atom_fractions', 'compute_similarity_variable', 'atoms_to_Hill', 
     'parse_simple_formula', 'parse_nested_formula', 'CAS_by_number',
     'periods', 'groups', 'blocks', 'homonuclear_elemental_gases',
-    'charge_from_formula', 'serialize_formula'
+    'charge_from_formula', 'serialize_formula', 'atoms_to_array',
 )
+import numpy as np
 import os
 import re
 import string
@@ -209,17 +210,17 @@ class PeriodicTable:
     Element
     
     '''
-    __slots__ = ('numerical_index', 'symbol_index',
-                 'name_index', 'CAS_index', 'all_indexes')
+    __slots__ = ('elements', 'numerical_index', 'symbol_index',
+                 'name_index', 'CAS_index', 'indexes')
     def __init__(self, elements):
+        self.elements = elements = tuple(elements)
         self.numerical_index = numerical_index = {}
         self.symbol_index = symbol_index = {}
         self.name_index = name_index = {}
         self.CAS_index = CAS_index = {}
-        self.all_indexes = (symbol_index, numerical_index,
+        self.indexes = (symbol_index, numerical_index,
                             name_index, CAS_index)
         for e in elements:
-            numerical_index[e.number] = e
             numerical_index[str(e.number)] = e
             symbol_index[e.symbol] = e
             name_index[e.name] = e
@@ -227,7 +228,7 @@ class PeriodicTable:
             CAS_index[e.CAS] = e
             
     def __contains__(self, key):
-        for i in self.all_indexes:
+        for i in self.indexes:
             if key in i: return True
         return False
 
@@ -235,15 +236,11 @@ class PeriodicTable:
         return 118
 
     def __iter__(self):
-        return (self.numerical_index[i] for i in range(1,119))
+        return iter(self.elements)
 
     def __getitem__(self, key):
-        for i in self.all_indexes:
+        for i in self.indexes:
             if key in i: return i[key]
-        try:
-            return self.numerical_index[int(key)]
-        except KeyError:
-            raise KeyError('key is not in the periodic table')
 
 
 class Element(object):
@@ -329,6 +326,9 @@ class Element(object):
         self.smiles = '[' + self.symbol + ']'
         self.PubChem = PubChem
 
+    def __repr__(self):
+        return f"<{type(self).__name__}: {self.symbol}>"
+
 
 element_list = []
 with open(os.path.join(folder, 'element.txt'), 'rb') as f:
@@ -365,6 +365,7 @@ with open(os.path.join(folder, 'element.txt'), 'rb') as f:
 
 #: Single instance of the PeriodicTable class
 periodic_table = PeriodicTable(element_list)
+del element_list
 
 def compute_molecular_weight(atoms):
     r'''
@@ -815,3 +816,19 @@ def serialize_formula(formula):
         else:
             base +=  str(charge)
     return base
+
+def atoms_to_array(atoms: dict) -> np.ndarray:
+    symbol_index = periodic_table.symbol_index
+    array = np.zeros(118)
+    for symbol, value in atoms.items():
+        index = symbol_index[symbol].number - 1
+        array[index] = value
+    return array
+
+def array_to_atoms(array: np.ndarray) -> dict:
+    index, = np.where(array != 0.)
+    values = array[index]
+    elements = periodic_table.elements
+    symbols = [elements[i].symbol for i in index]
+    return dict(zip(symbols, values))
+        
\ No newline at end of file
